@@ -88,6 +88,109 @@ _snapd_json_get_object (JsonObject *object, const gchar *name)
         return NULL;
 }
 
+gboolean
+_snapd_json_parse_time_span (const gchar *time_span_string, GTimeSpan *time_span)
+{
+    /* Examples:
+          3y
+          1y5d
+          4h32m2s
+
+       Valid time units: y w d h m s ms us µs ns
+
+       Since GTimeSpan is in microseconds, ns will be discarded.
+     */
+
+    GTimeSpan current_value = 0;
+    if (time_span_string == NULL)
+        return FALSE;
+    gchar *p = (gchar *)time_span_string;
+
+    *time_span = 0;
+    if (*p == '-')
+        p++;
+
+    for (;*p != 0; p++) {
+        switch (*p) {
+        case '0':
+        case '1':
+        case '2':
+        case '3':
+        case '4':
+        case '5':
+        case '6':
+        case '7':
+        case '8':
+        case '9':
+            current_value *= 10;
+            current_value += (GTimeSpan)((*p) - '0');
+            break;
+        case 'y':
+            *time_span += current_value * 365 * G_TIME_SPAN_DAY;
+            current_value = 0;
+            break;
+        case 'w':
+            *time_span += current_value * 7 * G_TIME_SPAN_DAY;
+            current_value = 0;
+            break;
+        case 'd':
+            *time_span += current_value * G_TIME_SPAN_DAY;
+            current_value = 0;
+            break;
+        case 'h':
+            *time_span += current_value * G_TIME_SPAN_HOUR;
+            current_value = 0;
+            break;
+        case 'm':
+            if (*(p+1) == 's') {
+                *time_span += current_value * G_TIME_SPAN_MILLISECOND;
+                p++;
+            } else {
+                *time_span += current_value * G_TIME_SPAN_MINUTE;
+            }
+            current_value = 0;
+            break;
+        case 's':
+            *time_span += current_value * G_TIME_SPAN_SECOND;
+            current_value = 0;
+            break;
+        case '\xc2': // first byte of µ
+            p++;
+            if (*p != '\xb5') { // it's not µ
+                *time_span = 0;
+                return FALSE;
+            }
+            // continue like it is 'u'
+        case 'u':
+            p++;
+            if (*p == 's') {
+                *time_span += current_value; // microseconds
+                current_value = 0;
+            } else {
+                *time_span = 0;
+                return FALSE;
+            }
+            break;
+        case 'n':
+            p++;
+            if (*p == 's') {
+                current_value = 0;
+            } else {
+                *time_span = 0;
+                return FALSE;
+            }
+            break;
+        default:
+            *time_span = 0;
+            return FALSE;
+        }
+    }
+    if (*time_span_string == '-') {
+        *time_span *= -1;
+    }
+    return TRUE;
+}
+
 static gboolean
 parse_date (const gchar *date_string, gint *year, gint *month, gint *day)
 {
@@ -122,10 +225,11 @@ parse_time (const gchar *time_string, gint *hour, gint *minute, gdouble *seconds
         if (tokens[1] == NULL)
             return FALSE;
         *minute = atoi (tokens[1]);
-        if (tokens[2] != NULL)
+        if (tokens[2] != NULL) {
             *seconds = g_ascii_strtod (tokens[2], NULL);
-        else
+        } else {
             *seconds = 0.0;
+        }
 
         return TRUE;
     }
@@ -142,8 +246,33 @@ is_timezone_prefix (gchar c)
     return c == '+' || c == '-' || c == 'Z';
 }
 
+static int
+parse_nanoseconds(gchar *token)
+{
+    gchar *nanostr;
+    int nanosecs;
+    size_t nanostr_len;
+
+    // find the decimal dot
+    for(nanostr = token; (*nanostr != '.') && (*nanostr != 0); nanostr++);
+
+    // no decimal value
+    if (*nanostr == 0)
+        return 0;
+
+    nanostr++; // jump over the dot
+    nanosecs = atoi(nanostr);
+
+    // RFC3999 removes trailing zeros, so we must complete up to nine decimals
+    nanostr_len = strlen(nanostr);
+    if (nanostr_len < 9)
+        for (int i = 0; i < (9 - nanostr_len); i++)
+            nanosecs *= 10;
+    return nanosecs;
+}
+
 GDateTime *
-_snapd_json_get_date_time (JsonObject *object, const gchar *name)
+_snapd_json_get_date_time (JsonObject *object, const gchar *name, int *nanoseconds)
 {
     const gchar *value = _snapd_json_get_string (object, name, NULL);
     if (value == NULL)
@@ -184,6 +313,8 @@ _snapd_json_get_date_time (JsonObject *object, const gchar *name)
     if (timezone == NULL)
         timezone = g_time_zone_new_local ();
 
+    if (nanoseconds != NULL)
+        *nanoseconds = parse_nanoseconds(tokens[1]);
     return g_date_time_new (timezone, year, month, day, hour, minute, seconds);
 }
 
@@ -521,6 +652,119 @@ _snapd_json_get_async_result (JsonObject *response, GError **error)
     return g_strdup (json_node_get_string (change_node));
 }
 
+static GStrv
+create_str_array_from_jsonarray (JsonArray *data) {
+    if (data == NULL)
+        return NULL;
+
+    guint len = json_array_get_length (data);
+    GStrv list = g_malloc0_n (1 + len, sizeof(gchar *));
+
+    for (guint i = 0; i <len; i++) {
+        JsonNode *node = json_array_get_element (data, i);
+        if (node == NULL || json_node_get_value_type (node) != G_TYPE_STRING) {
+            g_strfreev (list);
+            return NULL;
+        }
+        list[i] = g_strdup(json_node_get_string (node));
+    }
+    return list;
+}
+
+static gchar *
+get_int_as_string (JsonObject *object, const gchar *name)
+{
+    JsonNode *node = json_object_get_member (object, name);
+    if (node == NULL)
+        return NULL;
+    if (json_node_get_value_type (node) == G_TYPE_INT64)
+        return g_strdup_printf("%" G_GINT64_FORMAT, json_node_get_int (node));
+    else if (json_node_get_value_type (node) == G_TYPE_STRING)
+        return g_strdup(json_node_get_string (node));
+    return NULL;
+}
+
+static SnapdNotice *
+parse_notice (JsonObject *object)
+{
+    int last_occurred_nanoseconds = 0;
+    g_autoptr(GDateTime) first_occurred = _snapd_json_get_date_time (object, "first-occurred", NULL);
+    g_autoptr(GDateTime) last_occurred = _snapd_json_get_date_time (object, "last-occurred", &last_occurred_nanoseconds);
+    g_autoptr(GDateTime) last_repeated = _snapd_json_get_date_time (object, "last-repeated", NULL);
+
+    GTimeSpan expire_after = 0, repeat_after = 0;
+    _snapd_json_parse_time_span (_snapd_json_get_string (object, "expire-after", NULL), &expire_after);
+    _snapd_json_parse_time_span (_snapd_json_get_string (object, "repeat-after", NULL), &repeat_after);
+
+    const gchar *notice_type_string = _snapd_json_get_string (object, "type", NULL);
+    SnapdNoticeType notice_type;
+    if (notice_type_string == NULL)
+        notice_type = SNAPD_NOTICE_TYPE_UNKNOWN;
+    else if (g_str_equal (notice_type_string, "change-update"))
+        notice_type = SNAPD_NOTICE_TYPE_CHANGE_UPDATE;
+    else if (g_str_equal (notice_type_string, "refresh-inhibit"))
+        notice_type = SNAPD_NOTICE_TYPE_REFRESH_INHIBIT;
+    else if (g_str_equal (notice_type_string, "snap-run-inhibit"))
+        notice_type = SNAPD_NOTICE_TYPE_SNAP_RUN_INHIBIT;
+    else
+        notice_type = SNAPD_NOTICE_TYPE_UNKNOWN;
+
+    g_autoptr(GHashTable) last_data = NULL;
+    if (json_object_has_member (object, "last-data")) {
+        last_data = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
+        JsonObject *data_dict = _snapd_json_get_object (object, "last-data");
+
+        JsonObjectIter iter;
+        json_object_iter_init (&iter, data_dict);
+        const gchar *member_name;
+        JsonNode *member_node;
+        while (json_object_iter_next (&iter, &member_name, &member_node))
+            g_hash_table_insert (last_data, g_strdup (member_name), g_strdup (json_node_get_string (member_node)));
+    }
+    g_autofree gchar *user_id = get_int_as_string (object, "user-id");
+    return g_object_new (SNAPD_TYPE_NOTICE,
+                         "id", _snapd_json_get_string (object, "id", NULL),
+                         "user-id", user_id,
+                         "notice-type", notice_type,
+                         "key", _snapd_json_get_string (object, "key", NULL),
+                         "first-occurred", first_occurred,
+                         "last-occurred", last_occurred,
+                         "last-occurred-nanoseconds", last_occurred_nanoseconds,
+                         "last-repeated", last_repeated,
+                         "occurrences", _snapd_json_get_int (object, "occurrences", -1),
+                         "expire-after", expire_after,
+                         "repeat-after", repeat_after,
+                         "last-data", last_data,
+                         NULL);
+}
+
+GPtrArray *
+_snapd_json_parse_notices (JsonNode *node, GError **error)
+{
+    if (json_node_get_value_type (node) != JSON_TYPE_ARRAY) {
+        g_set_error (error,
+                     SNAPD_ERROR,
+                     SNAPD_ERROR_READ_FAILED,
+                     "Unexpected change type");
+        return NULL;
+    }
+    JsonArray *array = json_node_get_array (node);
+    g_autoptr(GPtrArray) notices = g_ptr_array_new_with_free_func (g_object_unref);
+    for (guint i = 0; i < json_array_get_length (array); i++) {
+        JsonNode *node = json_array_get_element (array, i);
+
+        if (!JSON_NODE_HOLDS_OBJECT (node)) {
+            g_set_error (error, SNAPD_ERROR, SNAPD_ERROR_BAD_RESPONSE, "Invalid notice");
+            return NULL;
+        }
+        JsonObject *object = json_node_get_object (node);
+
+        g_ptr_array_add (notices, parse_notice (object));
+    }
+
+    return g_steal_pointer (&notices);
+}
+
 SnapdChange *
 _snapd_json_parse_change (JsonNode *node, GError **error)
 {
@@ -547,8 +791,27 @@ _snapd_json_parse_change (JsonNode *node, GError **error)
         }
         JsonObject *object = json_node_get_object (node);
         JsonObject *progress = _snapd_json_get_object (object, "progress");
-        g_autoptr(GDateTime) spawn_time = _snapd_json_get_date_time (object, "spawn-time");
-        g_autoptr(GDateTime) ready_time = _snapd_json_get_date_time (object, "ready-time");
+        g_autoptr(GDateTime) spawn_time = _snapd_json_get_date_time (object, "spawn-time", NULL);
+        g_autoptr(GDateTime) ready_time = _snapd_json_get_date_time (object, "ready-time", NULL);
+        JsonObject *data = _snapd_json_get_object (object, "data");
+        g_autoptr(SnapdTaskData) task_data = NULL;
+        if (data != NULL) {
+            JsonNode *affected_snaps_node = json_object_get_member (data, "affected-snaps");
+            if (affected_snaps_node != NULL) {
+                if (json_node_get_value_type (affected_snaps_node) != JSON_TYPE_ARRAY) {
+                    g_set_error (error,
+                                SNAPD_ERROR,
+                                SNAPD_ERROR_READ_FAILED,
+                                "Unexpected affected-snaps type");
+                    return NULL;
+                }
+                JsonArray *affected_snaps = json_node_get_array (affected_snaps_node);
+                g_auto(GStrv) affected_snaps_array = create_str_array_from_jsonarray (affected_snaps);
+                task_data = g_object_new (SNAPD_TYPE_TASK_DATA,
+                                          "affected-snaps", affected_snaps_array,
+                                          NULL);
+            }
+        }
 
         g_autoptr(SnapdTask) t = g_object_new (SNAPD_TYPE_TASK,
                                                "id", _snapd_json_get_string (object, "id", NULL),
@@ -560,12 +823,34 @@ _snapd_json_parse_change (JsonNode *node, GError **error)
                                                "progress-total", progress != NULL ? _snapd_json_get_int (progress, "total", 0) : 0,
                                                "spawn-time", spawn_time,
                                                "ready-time", ready_time,
+                                               "data", task_data,
                                                NULL);
         g_ptr_array_add (tasks, g_steal_pointer (&t));
     }
 
-    g_autoptr(GDateTime) main_spawn_time = _snapd_json_get_date_time (object, "spawn-time");
-    g_autoptr(GDateTime) main_ready_time = _snapd_json_get_date_time (object, "ready-time");
+    g_autoptr(GDateTime) main_spawn_time = _snapd_json_get_date_time (object, "spawn-time", NULL);
+    g_autoptr(GDateTime) main_ready_time = _snapd_json_get_date_time (object, "ready-time", NULL);
+
+    g_autoptr(SnapdChangeData) data = NULL;
+    JsonObject *autorefresh_data = _snapd_json_get_object (object, "data");
+    const gchar *kind = _snapd_json_get_string (object, "kind", "");
+
+    // Currently, only one kind of Change can have DATA field, so this is quite "hardcoded". When more
+    // Change kinds have DATA field, new subclasses of SNAPD_TYPE_CHANGE_DATA must be created, and
+    // the code in QT's snapd-change-data.c file must be completed to manage the new types.
+    if (g_str_equal (kind, "auto-refresh") && (autorefresh_data != NULL)) {
+
+        g_autoptr(JsonArray) snap_names_json = _snapd_json_get_array (autorefresh_data, "snap-names");
+        g_auto(GStrv) snap_names = create_str_array_from_jsonarray (snap_names_json);
+
+        g_autoptr(JsonArray) refresh_forced_json = _snapd_json_get_array (autorefresh_data, "refresh-forced");
+        g_auto(GStrv) refresh_forced = create_str_array_from_jsonarray (refresh_forced_json);
+
+        data = g_object_new (SNAPD_TYPE_AUTOREFRESH_CHANGE_DATA,
+                             "snap-names", snap_names,
+                             "refresh-forced", refresh_forced,
+                             NULL);
+    }
 
     return g_object_new (SNAPD_TYPE_CHANGE,
                          "id", _snapd_json_get_string (object, "id", NULL),
@@ -577,6 +862,7 @@ _snapd_json_parse_change (JsonNode *node, GError **error)
                          "spawn-time", main_spawn_time,
                          "ready-time", main_ready_time,
                          "error", _snapd_json_get_string (object, "err", NULL),
+                         "data", data,
                          NULL);
 }
 
@@ -648,9 +934,9 @@ _snapd_json_parse_system_information (JsonNode *node, GError **error)
         }
     }
 
-    g_autoptr(GDateTime) refresh_hold = _snapd_json_get_date_time (refresh, "hold");
-    g_autoptr(GDateTime) refresh_last = _snapd_json_get_date_time (refresh, "last");
-    g_autoptr(GDateTime) refresh_next = _snapd_json_get_date_time (refresh, "next");
+    g_autoptr(GDateTime) refresh_hold = _snapd_json_get_date_time (refresh, "hold", NULL);
+    g_autoptr(GDateTime) refresh_last = _snapd_json_get_date_time (refresh, "last", NULL);
+    g_autoptr(GDateTime) refresh_next = _snapd_json_get_date_time (refresh, "next", NULL);
 
     return g_object_new (SNAPD_TYPE_SYSTEM_INFORMATION,
                          "architecture", architecture,
@@ -764,7 +1050,7 @@ _snapd_json_parse_snap (JsonNode *node, GError **error)
             JsonObject *c = json_node_get_object (channel_node);
 
             SnapdConfinement confinement = parse_confinement (_snapd_json_get_string (c, "confinement", ""));
-            g_autoptr(GDateTime) released_at = _snapd_json_get_date_time (c, "released-at");
+            g_autoptr(GDateTime) released_at = _snapd_json_get_date_time (c, "released-at", NULL);
 
             g_autoptr(SnapdChannel) channel = g_object_new (SNAPD_TYPE_CHANNEL,
                                                             "confinement", confinement,
@@ -793,8 +1079,8 @@ _snapd_json_parse_snap (JsonNode *node, GError **error)
     }
     g_ptr_array_add (common_ids_array, NULL);
 
-    g_autoptr(GDateTime) install_date = _snapd_json_get_date_time (object, "install-date");
-    g_autoptr(GDateTime) hold = _snapd_json_get_date_time (object, "hold");
+    g_autoptr(GDateTime) install_date = _snapd_json_get_date_time (object, "install-date", NULL);
+    g_autoptr(GDateTime) hold = _snapd_json_get_date_time (object, "hold", NULL);
 
     JsonObject *prices = _snapd_json_get_object (object, "prices");
     g_autoptr(GPtrArray) prices_array = g_ptr_array_new_with_free_func (g_object_unref);
@@ -879,6 +1165,11 @@ _snapd_json_parse_snap (JsonNode *node, GError **error)
             publisher_validation = SNAPD_PUBLISHER_VALIDATION_UNKNOWN;
     }
 
+    JsonObject *refresh_inhibit = _snapd_json_get_object (object, "refresh-inhibit");
+    g_autoptr(GDateTime) proceed_time = NULL;
+    if (refresh_inhibit != NULL)
+        proceed_time = _snapd_json_get_date_time (refresh_inhibit, "proceed-time", NULL);
+
     return g_object_new (SNAPD_TYPE_SNAP,
                          "apps", apps_array,
                          "base", _snapd_json_get_string (object, "base", NULL),
@@ -920,6 +1211,7 @@ _snapd_json_parse_snap (JsonNode *node, GError **error)
                          "trymode", _snapd_json_get_bool (object, "trymode", FALSE),
                          "version", _snapd_json_get_string (object, "version", NULL),
                          "website", _snapd_json_get_string (object, "website", NULL),
+                         "proceed-time", proceed_time,
                          NULL);
 }
 
