@@ -7,8 +7,7 @@
  * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
  */
 
-#ifndef __SNAPD_POST_SNAPCTL_H__
-#define __SNAPD_POST_SNAPCTL_H__
+#pragma once
 
 #include "snapd-request.h"
 
@@ -29,5 +28,3 @@ const gchar      *_snapd_post_snapctl_get_stderr_output (SnapdPostSnapctl *reque
 int               _snapd_post_snapctl_get_exit_code     (SnapdPostSnapctl *request);
 
 G_END_DECLS
-
-#endif /* __SNAPD_POST_SNAPCTL_H__ */
