@@ -15,6 +15,7 @@
 #endif
 
 #include <glib-object.h>
+#include "snapd-task-data.h"
 
 G_BEGIN_DECLS
 
@@ -43,6 +44,8 @@ GDateTime   *snapd_task_get_spawn_time     (SnapdTask *task);
 
 GDateTime   *snapd_task_get_ready_time     (SnapdTask *task);
 
+SnapdTaskData *snapd_task_get_data         (SnapdTask *task);
+
 G_END_DECLS
 
 #endif /* __SNAPD_TASK_H__ */
