@@ -39,6 +39,7 @@ class Q_DECL_EXPORT QSnapdSnap : public QSnapdWrappedObject
     Q_PROPERTY(bool devmode READ devmode)
     Q_PROPERTY(qint64 downloadSize READ downloadSize)
     Q_PROPERTY(QDateTime hold READ hold)
+    Q_PROPERTY(QDateTime proceedTime READ proceedTime)
     Q_PROPERTY(QString icon READ icon)
     Q_PROPERTY(QString id READ id)
     Q_PROPERTY(QDateTime installDate READ installDate)
@@ -86,6 +87,7 @@ public:
     bool devmode () const;
     qint64 downloadSize () const;
     QDateTime hold () const;
+    QDateTime proceedTime () const;
     QString icon () const;
     QString id () const;
     QDateTime installDate () const;
