@@ -12,6 +12,7 @@
 
 #include <glib-object.h>
 #include <gio/gio.h>
+#include <json-glib/json-glib.h>
 
 G_BEGIN_DECLS
 
@@ -41,6 +42,7 @@ typedef struct _MockSnap MockSnap;
 typedef struct _MockSnapshot MockSnapshot;
 typedef struct _MockTask MockTask;
 typedef struct _MockTrack MockTrack;
+typedef struct _MockNotice MockNotice;
 
 MockSnapd      *mock_snapd_new                    (void);
 
@@ -148,6 +150,8 @@ MockAccount    *mock_snapd_find_account_by_email  (MockSnapd     *snapd,
 
 MockChange     *mock_snapd_add_change             (MockSnapd     *snapd);
 
+const gchar    *mock_change_get_id                (MockChange    *change);
+
 MockTask       *mock_change_add_task              (MockChange    *change,
                                                    const gchar   *kind);
 
@@ -167,6 +171,9 @@ void            mock_task_set_spawn_time          (MockTask      *task,
 void            mock_task_set_ready_time          (MockTask      *task,
                                                    const gchar   *ready_time);
 
+void            mock_task_add_affected_snap       (MockTask      *task,
+                                                   const gchar *snap);
+
 void            mock_change_set_spawn_time        (MockChange    *change,
                                                    const gchar   *spawn_time);
 
@@ -477,6 +484,42 @@ void            mock_snapd_add_log                (MockSnapd     *snapd,
                                                    const gchar   *sid,
                                                    const gchar   *pid);
 
+void            mock_snap_set_proceed_time        (MockSnap      *snap,
+                                                   const gchar   *proceed_time);
+
+void            mock_change_add_data              (MockChange    *change,
+                                                   JsonNode      *data);
+
+void            mock_change_set_kind              (MockChange    *change,
+                                                   const gchar   *kind);
+MockNotice *    mock_snapd_add_notice             (MockSnapd     *snapd,
+                                                   const gchar   *id,
+                                                   const gchar   *key,
+                                                   const gchar   *type);
+
+void            mock_notice_set_user_id           (MockNotice    *notice,
+                                                   const gchar   *user_id);
+
+void            mock_notice_set_dates             (MockNotice    *notice,
+                                                   GDateTime     *first_occurred,
+                                                   GDateTime     *last_occurred,
+                                                   GDateTime     *last_repeat,
+                                                   int            occurrences);
+void            mock_notice_set_nanoseconds       (MockNotice    *notice,
+                                                   gint32         nanoseconds);
+
+void            mock_notice_set_expire_after      (MockNotice    *notice,
+                                                   const gchar   *expire_after);
+
+void            mock_notice_set_repeat_after      (MockNotice    *notice,
+                                                   const gchar   *repeat_after);
+
+void            mock_notice_add_data_pair         (MockNotice    *notice,
+                                                   const gchar   *entry,
+                                                   const gchar   *data);
+
+gchar *         mock_snapd_get_notices_parameters (MockSnapd     *snapd);
+
 G_END_DECLS
 
 #endif /* __MOCK_SNAPD_H__ */
